@@ -11,9 +11,9 @@ use Log::Log4perl::Level;
 use Log::Log4perl::Config;
 use Log::Log4perl::Appender;
 
-use constant DEBUG => 1;
+use constant _INTERNAL_DEBUG => 1;
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
    # set this to '1' if you're using a wrapper
    # around Log::Log4perl
@@ -300,7 +300,13 @@ Log::Log4perl - Log4j implementation for Perl
     
     --or--
     
+        # Check config every 10 secs
     Log::Log4perl::init_and_watch('/etc/log4perl.conf',10);
+
+    --or--
+
+        # Reload config on 'SIGHUP'
+    Log::Log4perl::init_and_watch('/etc/log4perl.conf', 'HUP');
     
     --then--
     
@@ -1255,6 +1261,34 @@ decision based upon these circumstantial facts.
 Check out L<Log::Log4perl::Filter> for detailed instructions 
 on how to use them.
 
+=head2 Performance
+
+The performance of Log::Log4perl calls obviously depends on a lot of things.
+but to give you a general idea, here's some rough numbers:
+
+On a Pentium 4 Linux box at 2.4 GHz, you'll get through
+
+=over 4
+
+=item *
+
+500,000 suppressed log statements per second
+
+=item *
+
+30,000 logged messages per second (using an in-memory appender)
+
+=item *
+
+init_and_watch delay mode: 300,000 suppressed, 30,000 logged.
+init_and_watch signal mode: 450,000 suppressed, 30,000 logged.
+
+=back
+
+Numbers depend on the complexity of the Log::Log4perl configuration.
+For a more detailed benchmark test, check the C<docs/benchmark.results.txt> 
+document in the Log::Log4perl distribution.
+
 =head1 Cool Tricks
 
 =head2 Shortcuts
@@ -1315,6 +1349,54 @@ the following URL schemes: http, https, ftp, wais, gopher, or file (followed by
 
 Don't use this feature with init_and_watch().
 
+=head2 Automatic reloading of changed configuration files
+
+Instead of just statically initializing Log::Log4perl via
+
+    Log::Log4perl->init($conf_file);
+
+there's a way to have Log::Log4perl periodically check for changes
+in the configuration and reload it if necessary:
+
+    Log::Log4perl->init($conf_file, $delay);
+
+In this mode, Log::Log4perl will examine the configuration file 
+C<$conf_file> every C<$delay> seconds for changes via the file's
+last modification timestamp. If the file has been updated, it will
+be reloaded and replace the current Log::Log4perl configuration.
+
+The way this works is that with every logger function called 
+(debug(), is_debug(), etc.), Log::Log4perl will check if the delay 
+interval has expired. If so, it will run a -M file check on the 
+configuration file. If its timestamp has been modified, the current
+configuration will be dumped and new content of the file will be
+loaded.
+
+This convenience comes at a price, though: Calling time() with every
+logging function call, especially the ones that are "suppressed" (!), 
+will slow down these Log4perl calls by about 40%.
+
+To alleviate this performance hit a bit, C<init_and_watch()> 
+can be configured to listen for a Unix signal to reload the 
+configuration instead:
+
+    Log::Log4perl->init($conf_file, 'HUP');
+
+This will set up a signal handler for SIGHUP and reload the configuration
+if the application receives this signal, e.g. via the C<kill> command:
+
+    kill -HUP pid
+
+where C<pid> is the process ID of the application. This will bring you back
+to about 85% of Log::Log4perl's normal execution speed for suppressed
+statements. For details, check out L<"Performance">. For more info
+on the signal handler, look for L<Log::Log4perl::Config::Watch/"SIGNAL MODE">.
+
+One thing to watch out for: If the configuration file contains a syntax
+or other fatal error, a running application will stop with C<die> if
+this damaged configuration will be loaded during runtime, triggered
+either by a signal or if the delay period expired and the change is 
+detected. This behaviour might change in the future.
 
 =head2 Perl Hooks in the Configuration File
 
@@ -2001,6 +2083,7 @@ our
     Paul Harrington <Paul-Harrington@deshaw.com>
     Erik Selberg <erik@selberg.com>
     Aaron Straup Cope <asc@vineyard.net>
+    Mac Yang <mac@proofpoint.com>
 
 =head1 COPYRIGHT AND LICENSE
 
